@@ -342,6 +342,16 @@ def add_banking(
     # Mount router to app (explicitly include in schema for OpenAPI docs)
     app.include_router(router, include_in_schema=True)
     
+    # Register scoped docs for landing page card (creates separate card like /auth, /payments)
+    from svc_infra.api.fastapi.docs.scoped import add_prefixed_docs
+    add_prefixed_docs(
+        app,
+        prefix=prefix,
+        title="Banking",
+        auto_exclude_from_root=True,
+        visible_envs=None,  # Show in all environments
+    )
+    
     # Store provider instance on app state for access in routes
     if not hasattr(app.state, "banking_provider"):
         app.state.banking_provider = banking
